@@ -10,12 +10,12 @@ package main
 import (
 	"net/http"
 	"os"
-
 	"os/signal"
 	"syscall"
 	"time"
 
 	"github.com/Lusitaniae/apache_exporter/collector"
+	"github.com/alecthomas/kingpin/v2"
 	"github.com/go-kit/log/level"
 	"github.com/prometheus/client_golang/prometheus"
 	"github.com/prometheus/client_golang/prometheus/promhttp"
@@ -23,21 +23,20 @@ import (
 	"github.com/prometheus/common/promlog/flag"
 	"github.com/prometheus/common/version"
 	"github.com/prometheus/exporter-toolkit/web"
-	"gopkg.in/alecthomas/kingpin.v2"
+	"github.com/prometheus/exporter-toolkit/web/kingpinflag"
 )
 
 var (
-	listeningAddress = kingpin.Flag("telemetry.address", "Address on which to expose metrics.").Default(":9117").String()
-	metricsEndpoint  = kingpin.Flag("telemetry.endpoint", "Path under which to expose metrics.").Default("/metrics").String()
-	scrapeURI        = kingpin.Flag("scrape_uri", "URI to apache stub status page.").Default("http://localhost/server-status/?auto").String()
-	hostOverride     = kingpin.Flag("host_override", "Override for HTTP Host header; empty string for no override.").Default("").String()
-	insecure         = kingpin.Flag("insecure", "Ignore server certificate if using https.").Bool()
-	configFile       = kingpin.Flag("web.config", "Path to config yaml file that can enable TLS or authentication.").Default("").String()
-	gracefulStop     = make(chan os.Signal)
+	metricsEndpoint = kingpin.Flag("telemetry.endpoint", "Path under which to expose metrics.").Default("/metrics").String()
+	scrapeURI       = kingpin.Flag("scrape_uri", "URI to apache stub status page.").Default("http://localhost/server-status/?auto").String()
+	hostOverride    = kingpin.Flag("host_override", "Override for HTTP Host header; empty string for no override.").Default("").String()
+	insecure        = kingpin.Flag("insecure", "Ignore server certificate if using https.").Bool()
+	toolkitFlags    = kingpinflag.AddFlags(kingpin.CommandLine, ":9117")
+	gracefulStop    = make(chan os.Signal, 1)
+	customHeaders   = kingpin.Flag("custom_headers", "Adds custom headers to the collector.").StringMap()
 )
 
 func main() {
-
 	promlogConfig := &promlog.Config{}
 
 	// Parse flags
@@ -53,17 +52,18 @@ func main() {
 	signal.Notify(gracefulStop, syscall.SIGQUIT)
 
 	config := &collector.Config{
-		ScrapeURI:    *scrapeURI,
-		HostOverride: *hostOverride,
-		Insecure:     *insecure,
+		ScrapeURI:     *scrapeURI,
+		HostOverride:  *hostOverride,
+		Insecure:      *insecure,
+		CustomHeaders: *customHeaders,
 	}
+
 	exporter := collector.NewExporter(logger, config)
 	prometheus.MustRegister(exporter)
 	prometheus.MustRegister(version.NewCollector("apache_exporter"))
 
 	level.Info(logger).Log("msg", "Starting apache_exporter", "version", version.Info())
 	level.Info(logger).Log("msg", "Build context", "build", version.BuildContext())
-	level.Info(logger).Log("msg", "Starting Server: ", "listen_address", *listeningAddress)
 	level.Info(logger).Log("msg", "Collect from: ", "scrape_uri", *scrapeURI)
 
 	// listener for the termination signals from the OS
@@ -72,7 +72,6 @@ func main() {
 		sig := <-gracefulStop
 		level.Info(logger).Log("msg", "caught sig: %+v. Wait 2 seconds...", "sig", sig)
 		time.Sleep(2 * time.Second)
-		level.Info(logger).Log("msg", "Terminate apache-exporter on port:", "listen_address", *listeningAddress)
 		os.Exit(0)
 	}()
 
@@ -86,13 +85,10 @@ func main() {
 			 </body>
 			 </html>`))
 	})
-	//log.Fatal(http.ListenAndServe(*listeningAddress, nil))
 
-	server := &http.Server{Addr: *listeningAddress}
-
-	if err := web.ListenAndServe(server, *configFile, logger); err != nil {
-		level.Error(logger).Log("msg", "Listening error", "reason", err)
+	server := &http.Server{}
+	if err := web.ListenAndServe(server, toolkitFlags, logger); err != nil {
+		level.Error(logger).Log("err", err)
 		os.Exit(1)
 	}
-
 }
